@@ -4,14 +4,14 @@ import (
 	"fmt"
 	"time"
 
-	"github.com/aws/aws-sdk-go/aws/awserr"
-
 	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/aws/awserr"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
-
 	awseks "github.com/aws/aws-sdk-go/service/eks"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
+	"github.com/pkg/errors"
+
 	"github.com/weaveworks/eksctl/pkg/actions/addon"
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/cfn/manager/fakes"
@@ -46,19 +46,15 @@ var _ = Describe("Delete", func() {
 				ClusterName: aws.String("my-cluster"),
 			}).Return(&awseks.DeleteAddonOutput{}, nil)
 
-			fakeStackManager.ListStacksMatchingReturns([]*cloudformation.Stack{
-				{
-					StackName: aws.String("eksctl-my-cluster-addon-my-addon"),
-				},
-			}, nil)
+			fakeStackManager.DescribeStackReturns(&cloudformation.Stack{StackName: aws.String("eksctl-my-cluster-addon-my-addon")}, nil)
 
 			err := manager.Delete(&api.Addon{
 				Name: "my-addon",
 			})
 			Expect(err).NotTo(HaveOccurred())
 
-			Expect(fakeStackManager.DeleteStackByNameCallCount()).To(Equal(1))
-			Expect(fakeStackManager.DeleteStackByNameArgsForCall(0)).To(Equal("eksctl-my-cluster-addon-my-addon"))
+			Expect(fakeStackManager.DeleteStackBySpecCallCount()).To(Equal(1))
+			Expect(*fakeStackManager.DeleteStackBySpecArgsForCall(0).StackName).To(Equal("eksctl-my-cluster-addon-my-addon"))
 		})
 
 		When("delete addon fails", func() {
@@ -83,13 +79,13 @@ var _ = Describe("Delete", func() {
 					ClusterName: aws.String("my-cluster"),
 				}).Return(&awseks.DeleteAddonOutput{}, nil)
 
-				fakeStackManager.ListStacksMatchingReturns([]*cloudformation.Stack{}, fmt.Errorf("foo"))
+				fakeStackManager.DescribeStackReturns(nil, fmt.Errorf("foo"))
 
 				err := manager.Delete(&api.Addon{
 					Name: "my-addon",
 				})
 
-				Expect(err).To(MatchError("failed to list stacks: foo"))
+				Expect(err).To(MatchError("failed to get stack: foo"))
 			})
 		})
 
@@ -100,11 +96,9 @@ var _ = Describe("Delete", func() {
 					ClusterName: aws.String("my-cluster"),
 				}).Return(&awseks.DeleteAddonOutput{}, nil)
 
-				fakeStackManager.DeleteStackByNameReturns(nil, fmt.Errorf("foo"))
-				fakeStackManager.ListStacksMatchingReturns([]*cloudformation.Stack{
-					{
-						StackName: aws.String("eksctl-my-cluster-addon-my-addon"),
-					},
+				fakeStackManager.DeleteStackBySpecReturns(nil, fmt.Errorf("foo"))
+				fakeStackManager.DescribeStackReturns(&cloudformation.Stack{
+					StackName: aws.String("eksctl-my-cluster-addon-my-addon"),
 				}, nil)
 
 				err := manager.Delete(&api.Addon{
@@ -112,8 +106,8 @@ var _ = Describe("Delete", func() {
 				})
 
 				Expect(err).To(MatchError(`failed to delete cloudformation stack "eksctl-my-cluster-addon-my-addon": foo`))
-				Expect(fakeStackManager.DeleteStackByNameCallCount()).To(Equal(1))
-				Expect(fakeStackManager.DeleteStackByNameArgsForCall(0)).To(Equal("eksctl-my-cluster-addon-my-addon"))
+				Expect(fakeStackManager.DeleteStackBySpecCallCount()).To(Equal(1))
+				Expect(*fakeStackManager.DeleteStackBySpecArgsForCall(0).StackName).To(Equal("eksctl-my-cluster-addon-my-addon"))
 			})
 		})
 
@@ -124,7 +118,7 @@ var _ = Describe("Delete", func() {
 					ClusterName: aws.String("my-cluster"),
 				}).Return(&awseks.DeleteAddonOutput{}, nil)
 
-				fakeStackManager.ListStacksMatchingReturns([]*cloudformation.Stack{}, nil)
+				fakeStackManager.DescribeStackReturns(nil, errors.Wrap(awserr.New("ValidationError", "test-err", nil), "nope"))
 
 				err := manager.Delete(&api.Addon{
 					Name: "my-addon",
@@ -132,7 +126,7 @@ var _ = Describe("Delete", func() {
 
 				Expect(err).NotTo(HaveOccurred())
 
-				Expect(fakeStackManager.DeleteStackByNameCallCount()).To(Equal(0))
+				Expect(fakeStackManager.DeleteStackBySpecCallCount()).To(Equal(0))
 			})
 		})
 
@@ -143,19 +137,16 @@ var _ = Describe("Delete", func() {
 					ClusterName: aws.String("my-cluster"),
 				}).Return(&awseks.DeleteAddonOutput{}, awserr.New(awseks.ErrCodeResourceNotFoundException, "", nil))
 
-				fakeStackManager.ListStacksMatchingReturns([]*cloudformation.Stack{
-					{
-						StackName: aws.String("eksctl-my-cluster-addon-my-addon"),
-					},
-				}, nil)
+				fakeStackManager.DescribeStackReturns(&cloudformation.Stack{StackName: aws.String("eksctl-my-cluster-addon-my-addon")}, nil)
+
 				err := manager.Delete(&api.Addon{
 					Name: "my-addon",
 				})
 
 				Expect(err).NotTo(HaveOccurred())
 
-				Expect(fakeStackManager.DeleteStackByNameCallCount()).To(Equal(1))
-				Expect(fakeStackManager.DeleteStackByNameArgsForCall(0)).To(Equal("eksctl-my-cluster-addon-my-addon"))
+				Expect(fakeStackManager.DeleteStackBySpecCallCount()).To(Equal(1))
+				Expect(*fakeStackManager.DeleteStackBySpecArgsForCall(0).StackName).To(Equal("eksctl-my-cluster-addon-my-addon"))
 			})
 		})
 
@@ -166,13 +157,13 @@ var _ = Describe("Delete", func() {
 					ClusterName: aws.String("my-cluster"),
 				}).Return(&awseks.DeleteAddonOutput{}, awserr.New(awseks.ErrCodeResourceNotFoundException, "", nil))
 
-				fakeStackManager.ListStacksMatchingReturns([]*cloudformation.Stack{}, nil)
+				fakeStackManager.DescribeStackReturns(nil, errors.Wrap(awserr.New("ValidationError", "test-err", nil), "nope"))
 				err := manager.Delete(&api.Addon{
 					Name: "my-addon",
 				})
 
 				Expect(err).To(MatchError("could not find addon or associated IAM stack to delete"))
-				Expect(fakeStackManager.DeleteStackByNameCallCount()).To(Equal(0))
+				Expect(fakeStackManager.DeleteStackBySpecCallCount()).To(Equal(0))
 			})
 		})
 	})
