@@ -1,8 +1,12 @@
 package ami_test
 
 import (
+	"context"
+
+	"github.com/aws/aws-sdk-go-v2/service/ssm"
+	ssmtypes "github.com/aws/aws-sdk-go-v2/service/ssm/types"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/service/ssm"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
 	"github.com/stretchr/testify/mock"
@@ -45,7 +49,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 						p = mockprovider.NewMockProvider()
 						addMockGetParameter(p, "/aws/service/eks/optimized-ami/1.12/amazon-linux-2/recommended/image_id", expectedAmi)
 						resolver := NewSSMResolver(p.MockSSM())
-						resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+						resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 					})
 
 					It("should not error", func() {
@@ -61,14 +65,14 @@ var _ = Describe("AMI Auto Resolution", func() {
 					})
 				})
 
-				Context("and ami is NOT available", func() {
+				Context("and ami is not available", func() {
 					BeforeEach(func() {
 
 						p = mockprovider.NewMockProvider()
 						addMockFailedGetParameter(p, "/aws/service/eks/optimized-ami/1.12/amazon-linux-2/recommended/image_id")
 
 						resolver := NewSSMResolver(p.MockSSM())
-						resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+						resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 					})
 
 					It("should return an error", func() {
@@ -97,7 +101,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 						p = mockprovider.NewMockProvider()
 						addMockGetParameter(p, "/aws/service/eks/optimized-ami/1.12/amazon-linux-2-gpu/recommended/image_id", expectedAmi)
 						resolver := NewSSMResolver(p.MockSSM())
-						resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+						resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 					})
 
 					It("should not error", func() {
@@ -130,7 +134,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 						addMockGetParameter(p, "/aws/service/ami-windows-latest/Windows_Server-2019-English-Full-EKS_Optimized-1.14/image_id", expectedAmi)
 
 						resolver := NewSSMResolver(p.MockSSM())
-						resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+						resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 
 						Expect(err).NotTo(HaveOccurred())
 						Expect(resolvedAmi).To(BeEquivalentTo(expectedAmi))
@@ -142,7 +146,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 						addMockGetParameter(p, "/aws/service/ami-windows-latest/Windows_Server-2019-English-Core-EKS_Optimized-1.15/image_id", expectedAmi)
 
 						resolver := NewSSMResolver(p.MockSSM())
-						resolvedAmi, err = resolver.Resolve(region, "1.15", instanceType, imageFamily)
+						resolvedAmi, err = resolver.Resolve(context.Background(), region, "1.15", instanceType, imageFamily)
 
 						Expect(err).NotTo(HaveOccurred())
 						Expect(resolvedAmi).To(BeEquivalentTo(expectedAmi))
@@ -151,7 +155,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 
 					It("should return an error for versions below 1.14", func() {
 						resolver := NewSSMResolver(p.MockSSM())
-						resolvedAmi, err = resolver.Resolve(region, "1.13", instanceType, imageFamily)
+						resolvedAmi, err = resolver.Resolve(context.Background(), region, "1.13", instanceType, imageFamily)
 
 						Expect(err).To(HaveOccurred())
 					})
@@ -168,7 +172,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 						addMockGetParameter(p, "/aws/service/ami-windows-latest/Windows_Server-20H2-English-Core-EKS_Optimized-1.21/image_id", expectedAmi)
 
 						resolver := NewSSMResolver(p.MockSSM())
-						resolvedAmi, err = resolver.Resolve(region, "1.21", instanceType, "WindowsServer20H2CoreContainer")
+						resolvedAmi, err = resolver.Resolve(context.Background(), region, "1.21", instanceType, "WindowsServer20H2CoreContainer")
 
 						Expect(err).NotTo(HaveOccurred())
 						Expect(resolvedAmi).To(BeEquivalentTo(expectedAmi))
@@ -177,7 +181,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 
 					It("should return an error for EKS versions below 1.21", func() {
 						resolver := NewSSMResolver(p.MockSSM())
-						_, err := resolver.Resolve(region, "1.20", instanceType, "WindowsServer20H2CoreContainer")
+						_, err := resolver.Resolve(context.Background(), region, "1.20", instanceType, "WindowsServer20H2CoreContainer")
 						Expect(err).To(HaveOccurred())
 						Expect(err).To(MatchError(ContainSubstring("Windows Server 20H2 Core requires EKS version 1.21 and above")))
 					})
@@ -192,7 +196,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 
 				It("should return an error", func() {
 					resolver := NewSSMResolver(p.MockSSM())
-					resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+					resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 
 					Expect(err).To(HaveOccurred())
 				})
@@ -210,7 +214,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 						p = mockprovider.NewMockProvider()
 						addMockGetParameter(p, "/aws/service/bottlerocket/aws-k8s-1.15/x86_64/latest/image_id", expectedAmi)
 						resolver := NewSSMResolver(p.MockSSM())
-						resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+						resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 					})
 
 					It("should not error", func() {
@@ -232,7 +236,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 						addMockFailedGetParameter(p, "/aws/service/bottlerocket/aws-k8s-1.15/x86_64/latest/image_id")
 
 						resolver := NewSSMResolver(p.MockSSM())
-						resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+						resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 					})
 
 					It("should return an error", func() {
@@ -259,7 +263,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 							p = mockprovider.NewMockProvider()
 							addMockGetParameter(p, "/aws/service/bottlerocket/aws-k8s-1.15/arm64/latest/image_id", expectedAmi)
 							resolver := NewSSMResolver(p.MockSSM())
-							resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+							resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 						})
 
 						It("should not error", func() {
@@ -281,7 +285,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 							addMockFailedGetParameter(p, "/aws/service/bottlerocket/aws-k8s-1.15/arm64/latest/image_id")
 
 							resolver := NewSSMResolver(p.MockSSM())
-							resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+							resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 						})
 
 						It("should return an error", func() {
@@ -311,7 +315,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 							p = mockprovider.NewMockProvider()
 							addMockGetParameter(p, "/aws/service/bottlerocket/aws-k8s-1.21-nvidia/x86_64/latest/image_id", expectedAmi)
 							resolver := NewSSMResolver(p.MockSSM())
-							resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+							resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 						})
 
 						It("does not return an error", func() {
@@ -331,7 +335,7 @@ var _ = Describe("AMI Auto Resolution", func() {
 							addMockFailedGetParameter(p, "/aws/service/bottlerocket/aws-k8s-1.21-nvidia/x86_64/latest/image_id")
 
 							resolver := NewSSMResolver(p.MockSSM())
-							resolvedAmi, err = resolver.Resolve(region, version, instanceType, imageFamily)
+							resolvedAmi, err = resolver.Resolve(context.Background(), region, version, instanceType, imageFamily)
 						})
 
 						It("errors", func() {
@@ -354,21 +358,21 @@ var _ = Describe("AMI Auto Resolution", func() {
 })
 
 func addMockGetParameter(p *mockprovider.MockProvider, name, amiID string) {
-	p.MockSSM().On("GetParameter",
+	p.MockSSM().On("GetParameter", mock.Anything,
 		mock.MatchedBy(func(input *ssm.GetParameterInput) bool {
 			return *input.Name == name
 		}),
 	).Return(&ssm.GetParameterOutput{
-		Parameter: &ssm.Parameter{
+		Parameter: &ssmtypes.Parameter{
 			Name:  aws.String(name),
-			Type:  aws.String("String"),
+			Type:  ssmtypes.ParameterTypeString,
 			Value: aws.String(amiID),
 		},
 	}, nil)
 }
 
 func addMockFailedGetParameter(p *mockprovider.MockProvider, name string) {
-	p.MockSSM().On("GetParameter",
+	p.MockSSM().On("GetParameter", mock.Anything,
 		mock.MatchedBy(func(input *ssm.GetParameterInput) bool {
 			return *input.Name == name
 		}),
