@@ -631,6 +631,10 @@ func ValidateNodeGroup(i int, ng *NodeGroup) error {
 		}
 	}
 
+	if ng.AMI != "" && ng.OverrideBootstrapCommand == nil {
+		return errors.Errorf("%s.overrideBootstrapCommand is required when using a custom AMI (%s.ami)", path, path)
+	}
+
 	if err := validateTaints(ng.Taints); err != nil {
 		return err
 	}
