@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"time"
 
+	"golang.org/x/sync/semaphore"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	"github.com/weaveworks/eksctl/pkg/drain/evictor"
@@ -15,6 +16,7 @@ import (
 	"github.com/pkg/errors"
 	"github.com/weaveworks/eksctl/pkg/eks"
 
+	cmap "github.com/orcaman/concurrent-map"
 	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/client-go/kubernetes"
 )
@@ -40,9 +42,10 @@ type NodeGroupDrainer struct {
 	waitTimeout         time.Duration
 	nodeDrainWaitPeriod time.Duration
 	undo                bool
+	parallel            int
 }
 
-func NewNodeGroupDrainer(clientSet kubernetes.Interface, ng eks.KubeNodeGroup, waitTimeout, maxGracePeriod, nodeDrainWaitPeriod time.Duration, undo, disableEviction bool) NodeGroupDrainer {
+func NewNodeGroupDrainer(clientSet kubernetes.Interface, ng eks.KubeNodeGroup, waitTimeout, maxGracePeriod, nodeDrainWaitPeriod time.Duration, undo, disableEviction bool, parallel int) NodeGroupDrainer {
 	ignoreDaemonSets := []metav1.ObjectMeta{
 		{
 			Namespace: "kube-system",
@@ -76,6 +79,7 @@ func NewNodeGroupDrainer(clientSet kubernetes.Interface, ng eks.KubeNodeGroup, w
 		waitTimeout:         waitTimeout,
 		nodeDrainWaitPeriod: nodeDrainWaitPeriod,
 		undo:                undo,
+		parallel:            parallel,
 	}
 }
 
@@ -101,15 +105,20 @@ func (n *NodeGroupDrainer) Drain() error {
 		return nil // no need to kill any pods
 	}
 
-	drainedNodes := sets.NewString()
+	drainedNodes := cmap.New()
+	ctx, cancel := context.WithTimeout(context.TODO(), n.waitTimeout)
+	defer cancel()
+
+	parallelLimit := int64(n.parallel)
+	sem := semaphore.NewWeighted(parallelLimit)
+	logger.Info("starting parallel draining, max in-flight of %d", parallelLimit)
 	// loop until all nodes are drained to handle accidental scale-up
 	// or any other changes in the ASG
-	timer := time.NewTimer(n.waitTimeout)
-	defer timer.Stop()
-
 	for {
 		select {
-		case <-timer.C:
+		case <-ctx.Done():
+			//need to use a different context
+			waitForAllRoutinesToFinish(context.TODO(), sem, parallelLimit)
 			return fmt.Errorf("timed out (after %s) waiting for nodegroup %q to be drained", n.waitTimeout, n.ng.NameString())
 		default:
 			nodes, err := n.clientSet.CoreV1().Nodes().List(context.TODO(), listOptions)
@@ -127,35 +136,58 @@ func (n *NodeGroupDrainer) Drain() error {
 			}
 
 			if newPendingNodes.Len() == 0 {
-				logger.Success("drained all nodes: %v", drainedNodes.List())
+				waitForAllRoutinesToFinish(ctx, sem, parallelLimit)
+				logger.Success("drained all nodes: %v", mapToList(drainedNodes.Items()))
 				return nil // no new nodes were seen
 			}
 
-			logger.Debug("already drained: %v", drainedNodes.List())
+			logger.Debug("already drained: %v", mapToList(drainedNodes.Items()))
 			logger.Debug("will drain: %v", newPendingNodes.List())
-
 			for i, node := range newPendingNodes.List() {
-				pending, err := n.evictPods(node)
-				if err != nil {
-					logger.Warning("pod eviction error (%q) on node %s", err, node)
-					time.Sleep(retryDelay)
-					continue
-				}
-				logger.Debug("%d pods to be evicted from %s", pending, node)
-				if pending == 0 {
-					drainedNodes.Insert(node)
+				if err := sem.Acquire(ctx, 1); err != nil {
+					logger.Critical("failed to acquire semaphore: %w", err)
 				}
 
-				// only wait if we're not on the last node of this iteration
-				if n.nodeDrainWaitPeriod > 0 && i < newPendingNodes.Len()-1 {
-					logger.Debug("waiting for %.0f seconds before draining next node", n.nodeDrainWaitPeriod.Seconds())
-					time.Sleep(n.nodeDrainWaitPeriod)
-				}
+				go func(i int, node string) {
+					defer sem.Release(1)
+					logger.Debug("starting drain of node %s", node)
+					pending, err := n.evictPods(node)
+					if err != nil {
+						logger.Warning("pod eviction error (%q) on node %s", err, node)
+						time.Sleep(retryDelay)
+						return
+					}
+
+					logger.Debug("%d pods to be evicted from %s", pending, node)
+					if pending == 0 {
+						drainedNodes.Set(node, nil)
+					}
+
+					if n.nodeDrainWaitPeriod > 0 {
+						logger.Debug("waiting for %.0f seconds before draining next node", n.nodeDrainWaitPeriod.Seconds())
+						time.Sleep(n.nodeDrainWaitPeriod)
+					}
+				}(i, node)
 			}
 		}
 	}
 }
 
+func waitForAllRoutinesToFinish(ctx context.Context, sem *semaphore.Weighted, size int64) {
+	if err := sem.Acquire(ctx, size); err != nil {
+		logger.Critical("failed to acquire semaphore while waiting for all routines to finish: %w", err)
+	}
+}
+
+func mapToList(m map[string]interface{}) []string {
+	list := []string{}
+	for key := range m {
+		list = append(list, key)
+	}
+
+	return list
+}
+
 func (n *NodeGroupDrainer) toggleCordon(cordon bool, nodes *corev1.NodeList) {
 	for _, node := range nodes.Items {
 		c := NewCordonHelper(&node, cordon)
@@ -180,6 +212,9 @@ func (n *NodeGroupDrainer) evictPods(node string) (int, error) {
 	if len(errs) > 0 {
 		return 0, fmt.Errorf("errs: %v", errs) // TODO: improve formatting
 	}
+	if list == nil {
+		return 0, nil
+	}
 	if w := list.Warnings(); w != "" {
 		logger.Warning(w)
 	}
