@@ -6,6 +6,9 @@ import (
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/aws/retry"
 	"github.com/aws/aws-sdk-go-v2/service/cloudformation"
+	"github.com/aws/aws-sdk-go-v2/service/elasticloadbalancing"
+	"github.com/aws/aws-sdk-go-v2/service/elasticloadbalancingv2"
+	"github.com/aws/aws-sdk-go-v2/service/ssm"
 	"github.com/aws/aws-sdk-go-v2/service/sts"
 
 	"github.com/weaveworks/eksctl/pkg/awsapi"
@@ -18,9 +21,12 @@ type ServicesV2 struct {
 
 	// mu guards initialization of SDK clients.
 	// All service methods should ensure that their initialization is guarded by mu.
-	mu             sync.Mutex
-	sts            *sts.Client
-	cloudformation *cloudformation.Client
+	mu                     sync.Mutex
+	sts                    *sts.Client
+	cloudformation         *cloudformation.Client
+	elasticloadbalancing   *elasticloadbalancing.Client
+	elasticloadbalancingV2 *elasticloadbalancingv2.Client
+	ssm                    *ssm.Client
 }
 
 // STSV2 implements the AWS STS service.
@@ -56,3 +62,33 @@ func (s *ServicesV2) CloudFormationV2() awsapi.CloudFormation {
 	}
 	return s.cloudformation
 }
+
+// ELB implements the AWS ELB service.
+func (s *ServicesV2) ELB() awsapi.ELB {
+	s.mu.Lock()
+	defer s.mu.Unlock()
+	if s.elasticloadbalancing == nil {
+		s.elasticloadbalancing = elasticloadbalancing.NewFromConfig(s.config)
+	}
+	return s.elasticloadbalancing
+}
+
+// ELBV2 implements the ELBV2 service.
+func (s *ServicesV2) ELBV2() awsapi.ELBV2 {
+	s.mu.Lock()
+	defer s.mu.Unlock()
+	if s.elasticloadbalancingV2 == nil {
+		s.elasticloadbalancingV2 = elasticloadbalancingv2.NewFromConfig(s.config)
+	}
+	return s.elasticloadbalancingV2
+}
+
+// SSM implements the AWS SSM service.
+func (s *ServicesV2) SSM() awsapi.SSM {
+	s.mu.Lock()
+	defer s.mu.Unlock()
+	if s.ssm == nil {
+		s.ssm = ssm.NewFromConfig(s.config)
+	}
+	return s.ssm
+}
