@@ -7,16 +7,18 @@ import (
 	"strings"
 	"time"
 
+	"github.com/aws/aws-sdk-go-v2/aws/retry"
+	"github.com/aws/aws-sdk-go-v2/service/elasticloadbalancing"
+	elbtypes "github.com/aws/aws-sdk-go-v2/service/elasticloadbalancing/types"
+	"github.com/aws/aws-sdk-go-v2/service/elasticloadbalancingv2"
+	elbv2types "github.com/aws/aws-sdk-go-v2/service/elasticloadbalancingv2/types"
+
 	"github.com/pkg/errors"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/awserr"
 	"github.com/aws/aws-sdk-go/service/ec2"
 	"github.com/aws/aws-sdk-go/service/ec2/ec2iface"
-	"github.com/aws/aws-sdk-go/service/elb"
-	"github.com/aws/aws-sdk-go/service/elb/elbiface"
-	"github.com/aws/aws-sdk-go/service/elbv2"
-	"github.com/aws/aws-sdk-go/service/elbv2/elbv2iface"
 	"github.com/kris-nova/logger"
 	corev1 "k8s.io/api/core/v1"
 
@@ -26,7 +28,6 @@ import (
 	cloudprovider "k8s.io/cloud-provider"
 	awsprovider "k8s.io/legacy-cloud-providers/aws"
 
-	"github.com/aws/aws-sdk-go/aws/request"
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 )
 
@@ -44,8 +45,20 @@ type loadBalancer struct {
 	ownedSecurityGroupIDs map[string]struct{}
 }
 
+// DescribeLoadBalancersAPI provides an interface to the AWS ELB service.
+type DescribeLoadBalancersAPI interface {
+	// DescribeLoadBalancers describes the specified load balancers or all load balancers.
+	DescribeLoadBalancers(ctx context.Context, params *elasticloadbalancing.DescribeLoadBalancersInput, optFns ...func(*elasticloadbalancing.Options)) (*elasticloadbalancing.DescribeLoadBalancersOutput, error)
+}
+
+// DescribeLoadBalancersAPIV2 provides an interface to the AWS ELBv2 service.
+type DescribeLoadBalancersAPIV2 interface {
+	// DescribeLoadBalancers describes the specified load balancers or all load balancers for ELBv2.
+	DescribeLoadBalancers(ctx context.Context, params *elasticloadbalancingv2.DescribeLoadBalancersInput, optFns ...func(*elasticloadbalancingv2.Options)) (*elasticloadbalancingv2.DescribeLoadBalancersOutput, error)
+}
+
 // Cleanup finds and deletes any dangling ELBs associated to a Kubernetes Service
-func Cleanup(ctx context.Context, ec2API ec2iface.EC2API, elbAPI elbiface.ELBAPI, elbv2API elbv2iface.ELBV2API,
+func Cleanup(ctx context.Context, ec2API ec2iface.EC2API, elbAPI DescribeLoadBalancersAPI, elbv2API DescribeLoadBalancersAPIV2,
 	kubernetesCS kubernetes.Interface, clusterConfig *api.ClusterConfig) error {
 
 	deadline, ok := ctx.Deadline()
@@ -153,7 +166,7 @@ func Cleanup(ctx context.Context, ec2API ec2iface.EC2API, elbAPI elbiface.ELBAPI
 	return nil
 }
 
-func getServiceLoadBalancer(ctx context.Context, ec2API ec2iface.EC2API, elbAPI elbiface.ELBAPI, clusterName string,
+func getServiceLoadBalancer(ctx context.Context, ec2API ec2iface.EC2API, elbAPI DescribeLoadBalancersAPI, clusterName string,
 	service *corev1.Service) (*loadBalancer, error) {
 	if service.Spec.Type != corev1.ServiceTypeLoadBalancer {
 		return nil, nil
@@ -218,7 +231,7 @@ func convertStringSetToSlice(set map[string]struct{}) []string {
 // Load balancers provisioned by the AWS cloud-provider integration are named k8s-elb-$loadBalancerName
 var sgNameRegex = regexp.MustCompile(`^k8s-elb-([^-]{1-32})$`)
 
-func deleteOrphanLoadBalancerSecurityGroups(ctx context.Context, ec2API ec2iface.EC2API, elbAPI elbiface.ELBAPI, clusterConfig *api.ClusterConfig) error {
+func deleteOrphanLoadBalancerSecurityGroups(ctx context.Context, ec2API ec2iface.EC2API, elbAPI DescribeLoadBalancersAPI, clusterConfig *api.ClusterConfig) error {
 	clusterName := clusterConfig.Metadata.Name
 	describeRequest := &ec2.DescribeSecurityGroupsInput{
 		Filters: []*ec2.Filter{
@@ -262,7 +275,7 @@ func deleteOrphanLoadBalancerSecurityGroups(ctx context.Context, ec2API ec2iface
 	return nil
 }
 
-func deleteFailedSecurityGroups(ctx aws.Context, ec2API ec2iface.EC2API, elbAPI elbiface.ELBAPI, securityGroups []*ec2.SecurityGroup) error {
+func deleteFailedSecurityGroups(ctx aws.Context, ec2API ec2iface.EC2API, elbAPI DescribeLoadBalancersAPI, securityGroups []*ec2.SecurityGroup) error {
 	for _, sg := range securityGroups {
 		// wait for the security group's load balancer to complete deletion
 		if err := ensureLoadBalancerDeleted(ctx, elbAPI, sg); err != nil {
@@ -275,7 +288,7 @@ func deleteFailedSecurityGroups(ctx aws.Context, ec2API ec2iface.EC2API, elbAPI
 	return nil
 }
 
-func ensureLoadBalancerDeleted(ctx context.Context, elbAPI elbiface.ELBAPI, sg *ec2.SecurityGroup) error {
+func ensureLoadBalancerDeleted(ctx context.Context, elbAPI DescribeLoadBalancersAPI, sg *ec2.SecurityGroup) error {
 	// extract load balancer name from the SG ID
 	match := sgNameRegex.FindStringSubmatch(*sg.GroupName)
 	if len(match) != 2 {
@@ -292,18 +305,20 @@ func ensureLoadBalancerDeleted(ctx context.Context, elbAPI elbiface.ELBAPI, sg *
 	defer cancelFunc()
 
 	for {
-		input := &elb.DescribeLoadBalancersInput{
-			LoadBalancerNames: []*string{aws.String(loadBalancerName)},
+		input := &elasticloadbalancing.DescribeLoadBalancersInput{
+			LoadBalancerNames: []string{loadBalancerName},
 		}
-
-		if _, err := elbAPI.DescribeLoadBalancersWithContext(timeoutCtx, input); err != nil {
-			if awsErr, ok := err.(awserr.Error); ok && awsErr.Code() == elb.ErrCodeAccessPointNotFoundException {
+		if _, err := elbAPI.DescribeLoadBalancers(timeoutCtx, input); err != nil {
+			switch {
+			case isELBNotFoundErr(err):
 				return nil
-			} else if err == context.DeadlineExceeded {
+			case err == context.DeadlineExceeded:
 				return errors.Wrap(err, "timed out looking up load balancer")
-			} else if request.IsErrorRetryable(err) {
+			case retry.IsErrorRetryables(retry.DefaultRetryables).IsErrorRetryable(err).Bool():
+				// This is not required when a retryer is configured. It exists to maintain the existing behaviour
+				// of manually retrying requests.
 				logger.Debug("retrying request after %v", lbRetryAfter)
-			} else {
+			default:
 				return err
 			}
 		}
@@ -352,7 +367,7 @@ func tagsIncludeClusterName(tags []*ec2.Tag, clusterName string) bool {
 	return false
 }
 
-func getSecurityGroupsOwnedByLoadBalancer(ctx context.Context, ec2API ec2iface.EC2API, elbAPI elbiface.ELBAPI,
+func getSecurityGroupsOwnedByLoadBalancer(ctx context.Context, ec2API ec2iface.EC2API, elbAPI DescribeLoadBalancersAPI,
 	clusterName string, loadBalancerName string, loadBalancerKind loadBalancerKind) (map[string]struct{}, error) {
 	if loadBalancerKind == network {
 		// V2 ELBs just use the Security Group of the EC2 instances
@@ -368,7 +383,7 @@ func getSecurityGroupsOwnedByLoadBalancer(ctx context.Context, ec2API ec2iface.E
 		return map[string]struct{}{}, nil
 	}
 
-	sgResponse, err := describeSecurityGroupsByID(ctx, ec2API, aws.StringValueSlice(lb.SecurityGroups))
+	sgResponse, err := describeSecurityGroupsByID(ctx, ec2API, lb.SecurityGroups)
 
 	if err != nil {
 		return nil, fmt.Errorf("error obtaining security groups for ELB: %s", err)
@@ -411,7 +426,7 @@ func getLoadBalancerKind(service *corev1.Service) loadBalancerKind {
 	return classic
 }
 
-func loadBalancerExists(ctx context.Context, ec2API ec2iface.EC2API, elbAPI elbiface.ELBAPI, elbv2API elbv2iface.ELBV2API, lb loadBalancer) (bool, error) {
+func loadBalancerExists(ctx context.Context, ec2API ec2iface.EC2API, elbAPI DescribeLoadBalancersAPI, elbv2API DescribeLoadBalancersAPIV2, lb loadBalancer) (bool, error) {
 	exists, err := elbExists(ctx, elbAPI, elbv2API, lb.name, lb.kind)
 	if err != nil {
 		return false, err
@@ -429,7 +444,7 @@ func loadBalancerExists(ctx context.Context, ec2API ec2iface.EC2API, elbAPI elbi
 	return len(sgResponse.SecurityGroups) != 0, nil
 }
 
-func elbExists(ctx context.Context, elbAPI elbiface.ELBAPI, elbv2API elbv2iface.ELBV2API,
+func elbExists(ctx context.Context, elbAPI DescribeLoadBalancersAPI, elbv2API DescribeLoadBalancersAPIV2,
 	name string, kind loadBalancerKind) (bool, error) {
 	if kind == network || kind == application {
 		return elbV2Exists(ctx, elbv2API, name)
@@ -438,24 +453,20 @@ func elbExists(ctx context.Context, elbAPI elbiface.ELBAPI, elbv2API elbv2iface.
 	return desc != nil, err
 }
 
-func describeClassicLoadBalancer(ctx context.Context, elbAPI elbiface.ELBAPI,
-	name string) (*elb.LoadBalancerDescription, error) {
+func describeClassicLoadBalancer(ctx context.Context, elbAPI DescribeLoadBalancersAPI,
+	name string) (*elbtypes.LoadBalancerDescription, error) {
 
-	request := &elb.DescribeLoadBalancersInput{
-		LoadBalancerNames: []*string{&name},
-	}
-
-	response, err := elbAPI.DescribeLoadBalancersWithContext(ctx, request)
+	response, err := elbAPI.DescribeLoadBalancers(ctx, &elasticloadbalancing.DescribeLoadBalancersInput{
+		LoadBalancerNames: []string{name},
+	})
 	if err != nil {
-		if awsError, ok := err.(awserr.Error); ok {
-			if awsError.Code() == elb.ErrCodeAccessPointNotFoundException {
-				return nil, nil
-			}
+		if isELBNotFoundErr(err) {
+			return nil, nil
 		}
 		return nil, err
 	}
 
-	var ret *elb.LoadBalancerDescription
+	var ret elbtypes.LoadBalancerDescription
 	switch {
 	case len(response.LoadBalancerDescriptions) > 1:
 		logger.Warning("found multiple load balancers with name: %s", name)
@@ -463,23 +474,25 @@ func describeClassicLoadBalancer(ctx context.Context, elbAPI elbiface.ELBAPI,
 	case len(response.LoadBalancerDescriptions) > 0:
 		ret = response.LoadBalancerDescriptions[0]
 	}
-	return ret, nil
+	return &ret, nil
 }
 
-func elbV2Exists(ctx context.Context, api elbv2iface.ELBV2API, name string) (bool, error) {
-	request := &elbv2.DescribeLoadBalancersInput{
-		Names: []*string{aws.String(name)},
-	}
-
-	_, err := api.DescribeLoadBalancersWithContext(ctx, request)
+func elbV2Exists(ctx context.Context, api DescribeLoadBalancersAPIV2, name string) (bool, error) {
+	_, err := api.DescribeLoadBalancers(ctx, &elasticloadbalancingv2.DescribeLoadBalancersInput{
+		Names: []string{name},
+	})
 	if err != nil {
-		if awsError, ok := err.(awserr.Error); ok {
-			if awsError.Code() == elbv2.ErrCodeLoadBalancerNotFoundException {
-				return false, nil
-			}
+		var notFoundErr *elbv2types.LoadBalancerNotFoundException
+		if errors.As(err, &notFoundErr) {
+			return false, nil
 		}
 		return false, err
 	}
 
 	return true, nil
 }
+
+func isELBNotFoundErr(err error) bool {
+	var notFoundErr *elbtypes.AccessPointNotFoundException
+	return errors.As(err, &notFoundErr)
+}
