@@ -15,10 +15,7 @@ import (
 	"github.com/aws/aws-sdk-go/service/cloudwatchlogs/cloudwatchlogsiface"
 	"github.com/aws/aws-sdk-go/service/ec2/ec2iface"
 	"github.com/aws/aws-sdk-go/service/eks/eksiface"
-	"github.com/aws/aws-sdk-go/service/elb/elbiface"
-	"github.com/aws/aws-sdk-go/service/elbv2/elbv2iface"
 	"github.com/aws/aws-sdk-go/service/iam/iamiface"
-	"github.com/aws/aws-sdk-go/service/ssm/ssmiface"
 	"github.com/aws/aws-sdk-go/service/sts/stsiface"
 
 	//"github.com/aws/aws-sdk-go/aws/awserr"
@@ -63,10 +60,8 @@ type MockProvider struct {
 	cfn            *mocks.CloudFormationAPI
 	eks            *mocks.EKSAPI
 	ec2            *mocks.EC2API
-	elb            *mocks.ELBAPI
-	elbv2          *mocks.ELBV2API
 	sts            *mocks.STSAPI
-	ssm            *mocks.SSMAPI
+	ssm            *mocksv2.SSM
 	iam            *mocks.IAMAPI
 	cloudtrail     *mocks.CloudTrailAPI
 	cloudwatchlogs *mocks.CloudWatchLogsAPI
@@ -74,6 +69,8 @@ type MockProvider struct {
 
 	stsV2            *mocksv2.STS
 	cloudformationV2 *mocksv2.CloudFormation
+	elb              *mocksv2.ELB
+	elbV2            *mocksv2.ELBV2
 }
 
 // NewMockProvider returns a new MockProvider
@@ -85,10 +82,8 @@ func NewMockProvider() *MockProvider {
 		cfn:            &mocks.CloudFormationAPI{},
 		eks:            &mocks.EKSAPI{},
 		ec2:            &mocks.EC2API{},
-		elb:            &mocks.ELBAPI{},
-		elbv2:          &mocks.ELBV2API{},
 		sts:            &mocks.STSAPI{},
-		ssm:            &mocks.SSMAPI{},
+		ssm:            &mocksv2.SSM{},
 		iam:            &mocks.IAMAPI{},
 		cloudtrail:     &mocks.CloudTrailAPI{},
 		cloudwatchlogs: &mocks.CloudWatchLogsAPI{},
@@ -96,6 +91,8 @@ func NewMockProvider() *MockProvider {
 
 		stsV2:            &mocksv2.STS{},
 		cloudformationV2: &mocksv2.CloudFormation{},
+		elb:              &mocksv2.ELB{},
+		elbV2:            &mocksv2.ELBV2{},
 	}
 }
 
@@ -119,6 +116,22 @@ func (m MockProvider) MockCloudFormationV2() *mocksv2.CloudFormation {
 	return m.cloudformationV2
 }
 
+func (m *MockProvider) ELB() awsapi.ELB {
+	return m.elb
+}
+
+func (m *MockProvider) MockELB() *mocksv2.ELB {
+	return m.elb
+}
+
+func (m *MockProvider) ELBV2() awsapi.ELBV2 {
+	return m.elbV2
+}
+
+func (m *MockProvider) MockELBV2() *mocksv2.ELBV2 {
+	return m.elbV2
+}
+
 // CloudFormation returns a representation of the CloudFormation API
 func (m MockProvider) CloudFormation() cloudformationiface.CloudFormationAPI { return m.cfn }
 
@@ -150,12 +163,6 @@ func (m MockProvider) MockEKS() *mocks.EKSAPI { return m.EKS().(*mocks.EKSAPI) }
 // EC2 returns a representation of the EC2 API
 func (m MockProvider) EC2() ec2iface.EC2API { return m.ec2 }
 
-// ELB returns a representation of the ELB API
-func (m MockProvider) ELB() elbiface.ELBAPI { return m.elb }
-
-// ELBV2 returns a representation of the ELBV2 API
-func (m MockProvider) ELBV2() elbv2iface.ELBV2API { return m.elbv2 }
-
 // MockEC2 returns a mocked EC2 API
 func (m MockProvider) MockEC2() *mocks.EC2API { return m.EC2().(*mocks.EC2API) }
 
@@ -166,10 +173,10 @@ func (m MockProvider) STS() stsiface.STSAPI { return m.sts }
 func (m MockProvider) MockSTS() *mocks.STSAPI { return m.STS().(*mocks.STSAPI) }
 
 // SSM returns a representation of the SSM API
-func (m MockProvider) SSM() ssmiface.SSMAPI { return m.ssm }
+func (m MockProvider) SSM() awsapi.SSM { return m.ssm }
 
 // MockSSM returns a mocked SSM API
-func (m MockProvider) MockSSM() *mocks.SSMAPI { return m.SSM().(*mocks.SSMAPI) }
+func (m MockProvider) MockSSM() *mocksv2.SSM { return m.ssm }
 
 // IAM returns a representation of the IAM API
 func (m MockProvider) IAM() iamiface.IAMAPI { return m.iam }
